#!/bin/sh
# -------------------------------------------------------------------
# Sample script for Unix-like systems, including macOS, Linux
# to extract metadata using exiftool for Archiware P5 archiving
#
# For Windows, see exifscript.bat
#
# The script accepts a filename as parameter and outputs metadata
# as key value pairs
#
# Example:
# exifscript.sh  IMG_0827.JPG
# returns
# user_dimensions {5472x3648} user_camera {Canon Canon EOS 70D} user_colorspace {sRGB} user_comment { }
#
# This requires to define metadata fields in the Archive Index named
# dimensions, camera, colorspace and comment
# The command below uses these tags:
# -ImageWidth -ImageHeight -Make -Model -ColorSpace -UserComment -ImageDescription
# and formats the output according to the expected key value pairs
#
# For the Documentation and download of exiftool, see
# https://exiftool.org/
#
# For a documentation of available tags, see
# https://exiftool.org/#supported
# Or execute "exiftool -list"
# -------------------------------------------------------------------

EXIFTOOL="exiftool -Charset UTF8 -m -q"

$EXIFTOOL -p 'user_dimensions {${ImageWidth}x${ImageHeight}} user_camera {${Make}-${Model}} user_colorspace {${ColorSpace}} user_comment {${UserComment} ${ImageDescription}}' $1 2>/dev/null